@@ -18,7 +18,7 @@ class BrokerMatch:
     """
     Represents a match returned by the broker.
     """
-    bit_string: str
+    bit_vector: str
     confidence: float
 
 
