@@ -1,2 +1,2 @@
 from .model import AttributeValuePair, AttributeSchema, Entity, EncodedEntity, EncoderConfig, EncoderRequest
-from .client import get_version, encode_entities, EncoderClient
+from .client import encode_entities, EncoderClient
