@@ -1,6 +1,5 @@
-import functools
 import urllib.parse
-from typing import List, Tuple
+from typing import List
 
 import requests
 
@@ -9,35 +8,18 @@ from .model import EncoderRequest, EncodedEntity
 from ..restutil import prepare_url_for_relative_urljoin, ApiError
 
 
-def get_version(base_url: str) -> Tuple[int]:
-    """
-    Gets the version of the encoder service hosted at the specified URL.
-
-    :param base_url: URL at which the encoder service is hosted
-    :return: Tuple of integers representing the running version
-    """
-    r = requests.get(base_url)
-    r.raise_for_status()
-
-    version_num = r.json()["version"][1:].split(".")
-    return tuple([int(v) for v in version_num])
-
-
-def encode_entities(base_url: str, request: EncoderRequest, force_include_schema=False) -> List[EncodedEntity]:
+def encode_entities(base_url: str, request: EncoderRequest) -> List[EncodedEntity]:
     """
     Encodes the entities contained within the request with the specified encoder configuration.
     Attribute schemas will be added to the request if present.
-    Make sure that the service you're connecting to supports attribute schemas before running an encoder request.
 
     :param base_url: URL at which the encoder service is hosted
     :param request: Encoder request
-    :param force_include_schema: ``True`` if attribute schemas should be generated even if none are specified,
-    ``False`` otherwise
     :return: List of encoded entities
     """
     base_url = prepare_url_for_relative_urljoin(base_url)
     url = urllib.parse.urljoin(base_url, "encode")
-    request = serialize_encoder_request(request, force_include_schema)
+    request = serialize_encoder_request(request)
 
     r = requests.post(url, json=request)
 
@@ -66,9 +48,14 @@ class EncoderClient:
 
         :param base_url: URL at which the encoder service is hosted
         """
-        self.version = get_version(base_url)
+        self.__base_url = base_url
 
-        if self.version >= (0, 2):
-            self.encode_entities = functools.partial(encode_entities, base_url, force_include_schema=True)
-        else:
-            self.encode_entities = functools.partial(encode_entities, base_url, force_include_schema=False)
+    def encode_entities(self, request: EncoderRequest):
+        """
+        Encodes the entities contained within the request with the specified encoder configuration.
+        Attribute schemas will be added to the request if present.
+
+        :param request: Encoder request
+        :return: List of encoded entities
+        """
+        return encode_entities(self.__base_url, request)
