@@ -10,6 +10,7 @@ class MatchConfig:
     match_function: str = "TRIGRAM_DICE"
     selection_strategy: str = "FULL_RESULT"
     threshold: float = 0
+    match_mode: str = "MATCH_MODE"
 
 
 @dataclass(frozen=True)
@@ -17,8 +18,8 @@ class MatchRequest:
     """
     Represents a request to match the domain bit strings against the range bit strings.
     """
-    domain_bit_strings: List[str] = field(default_factory=list)
-    range_bit_strings: List[str] = field(default_factory=list)
+    domain_bit_vectors: List[str] = field(default_factory=list)
+    range_bit_vectors: List[str] = field(default_factory=list)
     match_config: MatchConfig = field(default_factory=MatchConfig)
 
 
@@ -27,6 +28,6 @@ class Match:
     """
     Represents a match returned by the match service.
     """
-    domain_bit_string: str
-    range_bit_string: str
+    domain_bit_vector: str
+    range_bit_vector: str
     confidence: float
