@@ -1,19 +1,19 @@
 from typing import Dict
 
-from .model import MPIConfig, ResolveRequest, PseudonymMatch
+from .model import ClientConfig, ResolveRequest, PseudonymMatch
 from ..encoder.conversion import serialize_encoder_config
 
 
-def serialize_mpi_config(config: MPIConfig) -> Dict:
+def serialize_client_config(config: ClientConfig) -> Dict:
     """
-    Converts an MPI configuration into a dictionary.
+    Converts a client config into a dictionary.
 
-    :param config: MPI configuration to convert
-    :return: Converted MPI configuration
+    :param config: Client config to convert
+    :return: Converted client config
     """
     return {
         "domain": config.domain,
-        "pseudonyms": [pseudonym for pseudonym in config.pseudonyms]
+        "attributes": config.attributes
     }
 
 
@@ -25,9 +25,9 @@ def serialize_resolve_request(request: ResolveRequest) -> Dict:
     :return: Converted resolve request
     """
     return {
-        "mpi-configuration": serialize_mpi_config(request.mpi_config),
-        "encoder-configuration": serialize_encoder_config(request.encoder_config),
-        "attribute-list": request.attribute_list
+        "client-config": serialize_client_config(request.client_config),
+        "encoder-config": serialize_encoder_config(request.encoder_config),
+        "pseudonyms": request.pseudonyms
     }
 
 
